CheckruneRequest

Struct CheckruneRequest 

pub struct CheckruneRequest {
    pub rune: String,
    pub nodeid: Option<String>,
    pub method: Option<String>,
    pub params: Vec<String>,
}

Fields

rune: Stringnodeid: Option<String>method: Option<String>params: Vec<String>

Implementations

Source

impl CheckruneRequest

pub fn nodeid(&self) -> &str

Returns the value of nodeid, or the default value if nodeid is unset.

pub fn method(&self) -> &str

Returns the value of method, or the default value if method is unset.