pub struct FetchinvoiceRequest {
pub offer: String,
pub amount_msat: Option<Amount>,
pub quantity: Option<u64>,
pub recurrence_counter: Option<u64>,
pub recurrence_start: Option<f64>,
pub recurrence_label: Option<String>,
pub timeout: Option<f64>,
pub payer_note: Option<String>,
pub payer_metadata: Option<String>,
pub bip353: Option<String>,
}Fields
offer: Stringamount_msat: Option<Amount>quantity: Option<u64>recurrence_counter: Option<u64>recurrence_start: Option<f64>recurrence_label: Option<String>timeout: Option<f64>payer_note: Option<String>payer_metadata: Option<String>bip353: Option<String>Implementations
Sourceimpl FetchinvoiceRequest
impl FetchinvoiceRequest
Sourcepub fn quantity(&self) -> u64
pub fn quantity(&self) -> u64
Returns the value of quantity, or the default value if quantity is unset.
Sourcepub fn recurrence_counter(&self) -> u64
pub fn recurrence_counter(&self) -> u64
Returns the value of recurrence_counter, or the default value if recurrence_counter is unset.
Sourcepub fn recurrence_start(&self) -> f64
pub fn recurrence_start(&self) -> f64
Returns the value of recurrence_start, or the default value if recurrence_start is unset.
Sourcepub fn recurrence_label(&self) -> &str
pub fn recurrence_label(&self) -> &str
Returns the value of recurrence_label, or the default value if recurrence_label is unset.
Sourcepub fn timeout(&self) -> f64
pub fn timeout(&self) -> f64
Returns the value of timeout, or the default value if timeout is unset.
Sourcepub fn payer_note(&self) -> &str
pub fn payer_note(&self) -> &str
Returns the value of payer_note, or the default value if payer_note is unset.
Sourcepub fn payer_metadata(&self) -> &str
pub fn payer_metadata(&self) -> &str
Returns the value of payer_metadata, or the default value if payer_metadata is unset.