FunderupdateRequest

Struct FunderupdateRequest 

pub struct FunderupdateRequest {
Show 16 fields pub policy: Option<i32>, pub policy_mod: Option<Amount>, pub leases_only: Option<bool>, pub min_their_funding_msat: Option<Amount>, pub max_their_funding_msat: Option<Amount>, pub per_channel_min_msat: Option<Amount>, pub per_channel_max_msat: Option<Amount>, pub reserve_tank_msat: Option<Amount>, pub fuzz_percent: Option<u32>, pub fund_probability: Option<u32>, pub lease_fee_base_msat: Option<Amount>, pub lease_fee_basis: Option<u32>, pub funding_weight: Option<u32>, pub channel_fee_max_base_msat: Option<Amount>, pub channel_fee_max_proportional_thousandths: Option<u32>, pub compact_lease: Option<Vec<u8>>,
}

Fields

policy: Option<i32>policy_mod: Option<Amount>leases_only: Option<bool>min_their_funding_msat: Option<Amount>max_their_funding_msat: Option<Amount>per_channel_min_msat: Option<Amount>per_channel_max_msat: Option<Amount>reserve_tank_msat: Option<Amount>fuzz_percent: Option<u32>fund_probability: Option<u32>lease_fee_base_msat: Option<Amount>lease_fee_basis: Option<u32>funding_weight: Option<u32>channel_fee_max_base_msat: Option<Amount>channel_fee_max_proportional_thousandths: Option<u32>compact_lease: Option<Vec<u8>>

Implementations

Source

impl FunderupdateRequest

pub fn policy(&self) -> FunderupdatePolicy

Returns the enum value of policy, or the default if the field is unset or set to an invalid enum value.

pub fn set_policy(&mut self, value: FunderupdatePolicy)

Sets policy to the provided enum value.

pub fn leases_only(&self) -> bool

Returns the value of leases_only, or the default value if leases_only is unset.

pub fn fuzz_percent(&self) -> u32

Returns the value of fuzz_percent, or the default value if fuzz_percent is unset.

pub fn fund_probability(&self) -> u32

Returns the value of fund_probability, or the default value if fund_probability is unset.

pub fn lease_fee_basis(&self) -> u32

Returns the value of lease_fee_basis, or the default value if lease_fee_basis is unset.

pub fn funding_weight(&self) -> u32

Returns the value of funding_weight, or the default value if funding_weight is unset.

pub fn channel_fee_max_proportional_thousandths(&self) -> u32

Returns the value of channel_fee_max_proportional_thousandths, or the default value if channel_fee_max_proportional_thousandths is unset.

pub fn compact_lease(&self) -> &[u8]

Returns the value of compact_lease, or the default value if compact_lease is unset.