OfferRequest

Struct OfferRequest 

pub struct OfferRequest {
Show 13 fields pub amount: String, pub description: Option<String>, pub issuer: Option<String>, pub label: Option<String>, pub quantity_max: Option<u64>, pub absolute_expiry: Option<u64>, pub recurrence: Option<String>, pub recurrence_base: Option<String>, pub recurrence_paywindow: Option<String>, pub recurrence_limit: Option<u32>, pub single_use: Option<bool>, pub proportional_amount: Option<bool>, pub optional_recurrence: Option<bool>,
}

Fields

amount: Stringdescription: Option<String>issuer: Option<String>label: Option<String>quantity_max: Option<u64>absolute_expiry: Option<u64>recurrence: Option<String>recurrence_base: Option<String>recurrence_paywindow: Option<String>recurrence_limit: Option<u32>single_use: Option<bool>proportional_amount: Option<bool>optional_recurrence: Option<bool>

Implementations

Source

impl OfferRequest

pub fn description(&self) -> &str

Returns the value of description, or the default value if description is unset.

pub fn issuer(&self) -> &str

Returns the value of issuer, or the default value if issuer is unset.

pub fn label(&self) -> &str

Returns the value of label, or the default value if label is unset.

pub fn quantity_max(&self) -> u64

Returns the value of quantity_max, or the default value if quantity_max is unset.

pub fn absolute_expiry(&self) -> u64

Returns the value of absolute_expiry, or the default value if absolute_expiry is unset.

pub fn recurrence(&self) -> &str

Returns the value of recurrence, or the default value if recurrence is unset.

pub fn recurrence_base(&self) -> &str

Returns the value of recurrence_base, or the default value if recurrence_base is unset.

pub fn recurrence_paywindow(&self) -> &str

Returns the value of recurrence_paywindow, or the default value if recurrence_paywindow is unset.

pub fn recurrence_limit(&self) -> u32

Returns the value of recurrence_limit, or the default value if recurrence_limit is unset.

pub fn single_use(&self) -> bool

Returns the value of single_use, or the default value if single_use is unset.

pub fn proportional_amount(&self) -> bool

Returns the value of proportional_amount, or the default value if proportional_amount is unset.

pub fn optional_recurrence(&self) -> bool

Returns the value of optional_recurrence, or the default value if optional_recurrence is unset.