pub struct PluginResponse {
pub command: i32,
pub plugins: Vec<PluginPlugins>,
pub result: Option<String>,
}Fields
command: i32plugins: Vec<PluginPlugins>result: Option<String>Implementations
Sourceimpl PluginResponse
impl PluginResponse
Sourcepub fn command(&self) -> PluginSubcommand
pub fn command(&self) -> PluginSubcommand
Returns the enum value of command, or the default if the field is set to an invalid enum value.
Sourcepub fn set_command(&mut self, value: PluginSubcommand)
pub fn set_command(&mut self, value: PluginSubcommand)
Sets command to the provided enum value.