SendpayResponse

Struct SendpayResponse 

pub struct SendpayResponse {
Show 17 fields pub id: u64, pub groupid: Option<u64>, pub payment_hash: Vec<u8>, pub status: i32, pub amount_msat: Option<Amount>, pub destination: Option<Vec<u8>>, pub created_at: u64, pub amount_sent_msat: Option<Amount>, pub label: Option<String>, pub partid: Option<u64>, pub bolt11: Option<String>, pub bolt12: Option<String>, pub payment_preimage: Option<Vec<u8>>, pub message: Option<String>, pub completed_at: Option<u64>, pub created_index: Option<u64>, pub updated_index: Option<u64>,
}

Fields

id: u64groupid: Option<u64>payment_hash: Vec<u8>status: i32amount_msat: Option<Amount>destination: Option<Vec<u8>>created_at: u64amount_sent_msat: Option<Amount>label: Option<String>partid: Option<u64>bolt11: Option<String>bolt12: Option<String>payment_preimage: Option<Vec<u8>>message: Option<String>completed_at: Option<u64>created_index: Option<u64>updated_index: Option<u64>

Implementations

Source

impl SendpayResponse

pub fn groupid(&self) -> u64

Returns the value of groupid, or the default value if groupid is unset.

pub fn status(&self) -> SendpayStatus

Returns the enum value of status, or the default if the field is set to an invalid enum value.

pub fn set_status(&mut self, value: SendpayStatus)

Sets status to the provided enum value.

pub fn destination(&self) -> &[u8]

Returns the value of destination, or the default value if destination is unset.

pub fn label(&self) -> &str

Returns the value of label, or the default value if label is unset.

pub fn partid(&self) -> u64

Returns the value of partid, or the default value if partid is unset.

pub fn bolt11(&self) -> &str

Returns the value of bolt11, or the default value if bolt11 is unset.

pub fn bolt12(&self) -> &str

Returns the value of bolt12, or the default value if bolt12 is unset.

pub fn payment_preimage(&self) -> &[u8]

Returns the value of payment_preimage, or the default value if payment_preimage is unset.

pub fn message(&self) -> &str

Returns the value of message, or the default value if message is unset.

pub fn completed_at(&self) -> u64

Returns the value of completed_at, or the default value if completed_at is unset.

pub fn created_index(&self) -> u64

Returns the value of created_index, or the default value if created_index is unset.

pub fn updated_index(&self) -> u64

Returns the value of updated_index, or the default value if updated_index is unset.