pub struct WaitForwards {
pub status: Option<i32>,
pub in_channel: Option<String>,
pub in_htlc_id: Option<u64>,
pub in_msat: Option<Amount>,
pub out_channel: Option<String>,
}Fields
status: Option<i32>in_channel: Option<String>in_htlc_id: Option<u64>in_msat: Option<Amount>out_channel: Option<String>Implementations
Sourceimpl WaitForwards
impl WaitForwards
Sourcepub fn status(&self) -> WaitForwardsStatus
pub fn status(&self) -> WaitForwardsStatus
Returns the enum value of status, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: WaitForwardsStatus)
pub fn set_status(&mut self, value: WaitForwardsStatus)
Sets status to the provided enum value.
Sourcepub fn in_channel(&self) -> &str
pub fn in_channel(&self) -> &str
Returns the value of in_channel, or the default value if in_channel is unset.
Sourcepub fn in_htlc_id(&self) -> u64
pub fn in_htlc_id(&self) -> u64
Returns the value of in_htlc_id, or the default value if in_htlc_id is unset.
Sourcepub fn out_channel(&self) -> &str
pub fn out_channel(&self) -> &str
Returns the value of out_channel, or the default value if out_channel is unset.