pub struct WaitResponse {
pub subsystem: i32,
pub created: Option<u64>,
pub updated: Option<u64>,
pub deleted: Option<u64>,
pub details: Option<WaitDetails>,
pub forwards: Option<WaitForwards>,
pub invoices: Option<WaitInvoices>,
pub sendpays: Option<WaitSendpays>,
pub htlcs: Option<WaitHtlcs>,
pub chainmoves: Option<WaitChainmoves>,
pub channelmoves: Option<WaitChannelmoves>,
}Fields
subsystem: i32created: Option<u64>updated: Option<u64>deleted: Option<u64>details: Option<WaitDetails>forwards: Option<WaitForwards>invoices: Option<WaitInvoices>sendpays: Option<WaitSendpays>htlcs: Option<WaitHtlcs>chainmoves: Option<WaitChainmoves>channelmoves: Option<WaitChannelmoves>Implementations
Sourceimpl WaitResponse
impl WaitResponse
Sourcepub fn subsystem(&self) -> WaitSubsystem
pub fn subsystem(&self) -> WaitSubsystem
Returns the enum value of subsystem, or the default if the field is set to an invalid enum value.
Sourcepub fn set_subsystem(&mut self, value: WaitSubsystem)
pub fn set_subsystem(&mut self, value: WaitSubsystem)
Sets subsystem to the provided enum value.
Sourcepub fn created(&self) -> u64
pub fn created(&self) -> u64
Returns the value of created, or the default value if created is unset.