pub struct GetlogLog {
pub item_type: i32,
pub num_skipped: Option<u32>,
pub time: Option<String>,
pub source: Option<String>,
pub log: Option<String>,
pub node_id: Option<Vec<u8>>,
pub data: Option<Vec<u8>>,
}Fields
item_type: i32num_skipped: Option<u32>time: Option<String>source: Option<String>log: Option<String>node_id: Option<Vec<u8>>data: Option<Vec<u8>>Implementations
Sourceimpl GetlogLog
impl GetlogLog
Sourcepub fn item_type(&self) -> GetlogLogType
pub fn item_type(&self) -> GetlogLogType
Returns the enum value of item_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_item_type(&mut self, value: GetlogLogType)
pub fn set_item_type(&mut self, value: GetlogLogType)
Sets item_type to the provided enum value.
Sourcepub fn num_skipped(&self) -> u32
pub fn num_skipped(&self) -> u32
Returns the value of num_skipped, or the default value if num_skipped is unset.
Sourcepub fn source(&self) -> &str
pub fn source(&self) -> &str
Returns the value of source, or the default value if source is unset.